https://github.com/pyNFFT/pyNFFT
Flatiron Institute Nonuniform Fat Fourier Transform
https://finufft.readthedocs.io/en/latest/pythoninterface.html
https://github.com/jyhmiinlin/pynufft
https://github.com/peng-cao/mripy
https://github.com/jakevdp/nfft
https://github.com/jakevdp/nufftpy


GPU implementations:

https://mrirecon.github.io/bart/
http://gadgetron.github.io/
https://github.com/andyschwarzl/gpuNUFFT
http://impact.crhc.illinois.edu/mri.aspx
https://www.ismrm.org/mri_unbound/sequence.htm
